@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 1;
 
@@ -39,10 +39,13 @@ L<Map::Tube::Bucharest>,
 L<Map::Tube::Budapest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
+L<Map::Tube::Glasgow>,
 L<Map::Tube::Kazan>,
 L<Map::Tube::Kharkiv>,
 L<Map::Tube::Kiev>,
+L<Map::Tube::KoelnBonn>,
 L<Map::Tube::London>,
+L<Map::Tube::Lyon>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
 L<Map::Tube::NYC>,
@@ -76,6 +79,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.13
+0.14
 
 =cut
